from setuptools import setup

classifiers = [
   'Development Status :: 5 - Production/Stable',
   'Intended Audience :: Developers',
   'Intended Audience :: Science/Research',
   'License :: OSI Approved :: MIT License',
   'Programming Language :: Python :: 3'
   'Topic :: Software Development :: Libraries :: Python Modules',
   'Topic :: Scientific/Engineering :: Bio-Informatics'
]

setup(
  name='pypdc',
  version='0.0.2',
  description='Python asymptotic Partial Directed Coherence and Directed Coherence estimation package for brain connectivity analysis.'
  #License='MIT',
  #classifiers=classifiers,
  #platforms = ["Linux", "Mac OSX", "Windows", "Unix"],
  #keywords = ["Brain Connectivity", "PDC"],
  #install_requires=['']
)